import React, { useEffect } from "react";
import * as d3 from 'd3';

const Line = ({ data, width, height }: any) => {

    useEffect(() => {
        const margin = { top: 20, right: 20, bottom: 50, left: 70 };
        const w = width - margin.left - margin.right;
        const h = height - margin.top - margin.bottom;
        data.forEach((d: any) => {
            d.date = d3.timeParse('%e-%b-%y')(d.date);
        });

        const svg = d3
            .select("#linechart")
            .append("svg")
            .attr("width", width)
            .attr("height", height)
            .append("g")
            .attr("transform", `translate(${margin.left}, ${margin.top})`);

        const xDomain: any[] = d3.extent(data, (d: any) => d.date);
        const X = d3.scaleTime().domain(xDomain).range([0, w]);
        svg
            .append('g')
            .attr("transform", `translate(0, ${height})`)
            .call(d3.axisBottom(X).ticks(5));

        const yDomain: any[] = d3.extent(data, (d: any) => d.averagePrice);
        const Y = d3.scaleLinear().domain(yDomain).range([h, 0]);
        svg
            .append("g")
            .call(d3.axisLeft(Y).ticks(4).tickSize(-width));

        const line = d3
            .line()
            .curve(d3.curveMonotoneX)
            .x((d: any) => X(d.date))
            .y((d: any) => Y(d.averagePrice));

        svg
            .append("path")
            .data([data])
            .attr("class", "line")
            .attr("fill", "none")
            .attr("stroke", "steelblue")
            .attr("stroke-width", 1.5)
            .attr("d", line);

    }, [data, height, width]);

    return (
        <div id="linechart">

        </div>
    );
};

export default function TimeSeries(props: any) {

    return (
        <div>
            <h1>Affichage des données par une série temporelle</h1>
            <Line data={props.data} width={props.width} height={props.height} />
        </div>
    )
}