import React, { useEffect, useState } from "react";
import Footer from "./PageComponents/footer";
import Header from "./PageComponents/header";
import TabsContainer from "./Tabs/container";
import TimeSeries from "./Graphs/timeserie";
import BarChart from "./Graphs/barchart";
import PieChart from "./Graphs/piechart";
import Head from "next/head";

export default function Graphs() {

    const [averagePriceData, setAveragePriceData] = useState<any[]>([]);
    const [numberOfSalesData, setNumberOfSalesData] = useState<any[]>([]);
    const [salesByRegionData, setSalesByRegionData] = useState<any[]>([]);

    const fetchAveragePriceData = async () => {
        const response = await fetch(`https://localhost/average_price_per_month?page=1`, {
            method: 'GET',
            headers: {
                'Content-Type': 'application/json',
            },
        });

        if (!response.ok) return console.log('Data not found !');
        const data = await response.json();
        const res = data['hydra:member'].map((v: any) => {
            return {
                date: v.date.split('T')[0],
                averagePrice: v.averagePrice
            }
        });
        setAveragePriceData(res);
    }

    const fetchNumberOfSalesData = async () => {
        const response = await fetch(`https://localhost/number_sales_by_date?page=1`, {
            method: 'GET',
            headers: {
                'Content-Type': 'application/json',
            },
        });

        if (!response.ok) return console.log('Data not found !');
        const data = await response.json();
        const res = data['hydra:member'].map((v: any) => {
            return {
                startDate: v.startDate.split('T')[0],
                endDate: v.endDate.split('T')[0],
                numberSales: v.numberSales
            }
        });
        setNumberOfSalesData(res);
    }

    const fetchSalesByRegionData = async () => {
        const response = await fetch(`https://localhost/sales_by_region/2021?page=1`, {
            method: 'GET',
            headers: {
                'Content-Type': 'application/json',
            },
        });

        if (!response.ok) return console.log('Data not found !');
        const data = await response.json();
        const res = data['hydra:member'].map((v: any) => {
            return {
                region: v.region,
                numberSales: v.numberSales
            }
        });
        setSalesByRegionData(res);
    }

    useEffect(() => {
        fetchAveragePriceData();
        fetchNumberOfSalesData();
        fetchSalesByRegionData();
    }, [averagePriceData, numberOfSalesData, salesByRegionData]);

    // Component in each tab
    const tabs = [
        <TimeSeries key={0} tabLabel="Série temporelle" width={1000} height={500} data={averagePriceData} />,
        <BarChart key={1} tabLabel="Diagramme à barre" width={1000} height={500} data={numberOfSalesData} />,
        <PieChart key={2} tabLabel="Diagramme circulaire" width={1000} height={500} data={salesByRegionData} />
    ];

    return (
        <>
            <Head>
                <title>Graphs</title>
            </Head>
            <Header />
            <TabsContainer tabs={tabs} />
            <Footer />
        </>
    )
};